@@ -5,16 +5,12 @@
  */
 
 #include "ldapclientsearchconfig.h"
-#include <kldap/ldapserver.h>
+#include <kldapcore/ldapserver.h>
 
 #include <KConfig>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
 #include <qt6keychain/keychain.h>
-#endif
 using namespace QKeychain;
-using namespace KLDAP;
+using namespace KLDAPWidgets;
 
 class Q_DECL_HIDDEN LdapClientSearchConfig::LdapClientSearchConfigPrivate
 {
@@ -56,3 +52,5 @@ void LdapClientSearchConfig::clearWalletPassword()
     }
 }
 #endif
+
+#include "moc_ldapclientsearchconfig.cpp"
