@@ -5,46 +5,45 @@
  */
 
 #pragma once
-#include "kldap_export.h"
+#include "kldapwidgets_export.h"
 #include <KConfigGroup>
-#include <KLDAP/LdapServer>
+#include <KLDAPCore/LdapServer>
 #include <QObject>
 namespace QKeychain
 {
 class Job;
 }
-namespace KLDAP
+namespace KLDAPWidgets
 {
-class KLDAP_EXPORT LdapClientSearchConfigReadConfigJob : public QObject
+class KLDAPWIDGETS_EXPORT LdapClientSearchConfigReadConfigJob : public QObject
 {
     Q_OBJECT
 public:
     explicit LdapClientSearchConfigReadConfigJob(QObject *parent = nullptr);
     ~LdapClientSearchConfigReadConfigJob() override;
 
-    Q_REQUIRED_RESULT bool canStart() const;
+    [[nodiscard]] bool canStart() const;
     void start();
 
-    Q_REQUIRED_RESULT bool active() const;
+    [[nodiscard]] bool active() const;
     void setActive(bool newActive);
 
-    Q_REQUIRED_RESULT int serverIndex() const;
+    [[nodiscard]] int serverIndex() const;
     void setServerIndex(int newServerIndex);
 
-    Q_REQUIRED_RESULT KConfigGroup config() const;
+    [[nodiscard]] KConfigGroup config() const;
     void setConfig(const KConfigGroup &newConfig);
 
 Q_SIGNALS:
-    void configLoaded(const KLDAP::LdapServer &server);
+    void configLoaded(const KLDAPCore::LdapServer &server);
 
 private:
-    KLDAP_NO_EXPORT void readLdapPasswordFinished(QKeychain::Job *baseJob);
-    KLDAP_NO_EXPORT void readLdapClientConfigFinished();
-    KLDAP_NO_EXPORT void readConfig();
+    KLDAPWIDGETS_NO_EXPORT void readLdapClientConfigFinished();
+    KLDAPWIDGETS_NO_EXPORT void readConfig();
     int mServerIndex = -1;
     KConfigGroup mConfig;
     bool mActive = false;
-    KLDAP::LdapServer mServer;
+    KLDAPCore::LdapServer mServer;
 };
 
 }
