@@ -7,16 +7,11 @@
 #include "ldapclientsearchconfigwriteconfigjob.h"
 #include "ldapclient_debug.h"
 
-#include <KConfig>
-#include <kldap/ldapdn.h>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
+#include <kldapcore/ldapdn.h>
 #include <qt6keychain/keychain.h>
-#endif
 using namespace QKeychain;
 
-using namespace KLDAP;
+using namespace KLDAPWidgets;
 LdapClientSearchConfigWriteConfigJob::LdapClientSearchConfigWriteConfigJob(QObject *parent)
     : QObject(parent)
 {
@@ -108,10 +103,10 @@ void LdapClientSearchConfigWriteConfigJob::writeConfig()
     mConfig.writeEntry(prefix + QStringLiteral("Version%1").arg(mServerIndex), mServer.version());
     QString tmp;
     switch (mServer.security()) {
-    case KLDAP::LdapServer::TLS:
+    case KLDAPCore::LdapServer::TLS:
         tmp = QStringLiteral("TLS");
         break;
-    case KLDAP::LdapServer::SSL:
+    case KLDAPCore::LdapServer::SSL:
         tmp = QStringLiteral("SSL");
         break;
     default:
@@ -119,10 +114,10 @@ void LdapClientSearchConfigWriteConfigJob::writeConfig()
     }
     mConfig.writeEntry(prefix + QStringLiteral("Security%1").arg(mServerIndex), tmp);
     switch (mServer.auth()) {
-    case KLDAP::LdapServer::Simple:
+    case KLDAPCore::LdapServer::Simple:
         tmp = QStringLiteral("Simple");
         break;
-    case KLDAP::LdapServer::SASL:
+    case KLDAPCore::LdapServer::SASL:
         tmp = QStringLiteral("SASL");
         break;
     default:
@@ -136,12 +131,14 @@ void LdapClientSearchConfigWriteConfigJob::writeConfig()
     }
 }
 
-KLDAP::LdapServer LdapClientSearchConfigWriteConfigJob::server() const
+KLDAPCore::LdapServer LdapClientSearchConfigWriteConfigJob::server() const
 {
     return mServer;
 }
 
-void LdapClientSearchConfigWriteConfigJob::setServer(const KLDAP::LdapServer &server)
+void LdapClientSearchConfigWriteConfigJob::setServer(const KLDAPCore::LdapServer &server)
 {
     mServer = server;
 }
+
+#include "moc_ldapclientsearchconfigwriteconfigjob.cpp"
